==> gradle-6.8.1-all.zip: gradle-6.8.1/src/kotlin-dsl/org/gradle/kotlin/dsl/cache/GradleUserHomeServices.kt <==
/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.kotlin.dsl.cache

import org.gradle.api.internal.cache.StringInterner
import org.gradle.cache.CacheRepository
import org.gradle.cache.internal.CacheScopeMapping
import org.gradle.cache.internal.InMemoryCacheDecoratorFactory
import org.gradle.internal.file.FileAccessTimeJournal


internal
object GradleUserHomeServices {

    @Suppress("unused")
    fun createKotlinDslWorkspaceProvider(
        cacheRepository: CacheRepository,
        cacheScopeMapping: CacheScopeMapping,
        fileAccessTimeJournal: FileAccessTimeJournal,
        inMemoryCacheDecoratorFactory: InMemoryCacheDecoratorFactory,
        stringInterner: StringInterner
    ): KotlinDslWorkspaceProvider {
        return KotlinDslWorkspaceProvider(
            cacheRepository,
            cacheScopeMapping,
            fileAccessTimeJournal,
            inMemoryCacheDecoratorFactory,
            stringInterner
        )
    }
}

==> gradle-8.0.1-all.zip: gradle-8.0.1/src/kotlin-dsl/org/gradle/kotlin/dsl/cache/GradleUserHomeServices.kt <==
/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.kotlin.dsl.cache

import org.gradle.api.internal.cache.StringInterner
import org.gradle.cache.internal.CleanupActionDecorator
import org.gradle.api.internal.cache.CacheConfigurationsInternal
import org.gradle.cache.internal.InMemoryCacheDecoratorFactory
import org.gradle.cache.scopes.GlobalScopedCache
import org.gradle.internal.file.FileAccessTimeJournal
import org.gradle.internal.hash.ClassLoaderHierarchyHasher


internal
object GradleUserHomeServices {

    @Suppress("unused")
    fun createKotlinDslWorkspaceProvider(
        cacheRepository: GlobalScopedCache,
        fileAccessTimeJournal: FileAccessTimeJournal,
        inMemoryCacheDecoratorFactory: InMemoryCacheDecoratorFactory,
        stringInterner: StringInterner,
        classLoaderHasher: ClassLoaderHierarchyHasher,
        cleanupActionDecorator: CleanupActionDecorator,
        cacheConfigurations: CacheConfigurationsInternal
    ): KotlinDslWorkspaceProvider {
        return KotlinDslWorkspaceProvider(
            cacheRepository,
            fileAccessTimeJournal,
            inMemoryCacheDecoratorFactory,
            stringInterner,
            classLoaderHasher,
            cleanupActionDecorator,
            cacheConfigurations
        )
    }
}
